/* Handlebars Helpers - Dan Harper (http://github.com/danharper) */

/* This program is free software. It comes without any warranty, to
 * the extent permitted by applicable law. You can redistribute it
 * and/or modify it under the terms of the Do What The Fuck You Want
 * To Public License, Version 2, as published by Sam Hocevar. See
 * http://sam.zoy.org/wtfpl/COPYING for more details. */

/**
 *  Following lines make Handlebars helper function to work with all
 *  three such as Direct web, RequireJS AMD and Node JS.
 *  This concepts derived from UMD.
 *  @courtesy - https://github.com/umdjs/umd/blob/master/returnExports.js
 */

(function (root, factory) {
    if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like enviroments that support module.exports,
        // like Node.
        module.exports = factory(require('handlebars'));
    } else if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['handlebars'], factory);
    } else {
        // Browser globals (root is window)
        root.returnExports = factory(root.Handlebars);
    }
}(this, function (Handlebars) {

    /**
     * If Equals
     * if_eq this compare=that
     */
    Handlebars.registerHelper('if_eq', function(context, options) {
        if (context == options.hash.compare)
            return options.fn(this);
        return options.inverse(this);
    });

    /**
     * Unless Equals
     * unless_eq this compare=that
     */
    Handlebars.registerHelper('unless_eq', function(context, options) {
        if (context == options.hash.compare)
            return options.inverse(this);
        return options.fn(this);
    });

    Handlebars.registerHelper("ifPageExist", function(user_id){
        var current_userinfo = jQuery.parseJSON(localStorage["userinfo"]);
        var current_user_id = current_userinfo.user_info.user_id;
        var out = "";
        if(current_user_id == user_id){
            out = "greyBg";          
        }else{
            out = "";
        }
        return new Handlebars.SafeString(out); 
    });

    /**
     * If Admin
     * show proper icon
     */

    Handlebars.registerHelper("IfAdmin", function(admin_id){
        var current_userinfo = jQuery.parseJSON(localStorage["userinfo"]);
        var current_user_id = current_userinfo.user_info.user_id;
        if(admin_id == current_user_id){
            out = "img/group-admin.png";          
         }else{
            out = "img/group-icon.png"
         }
         console.log(out);
        return new Handlebars.SafeString(out); 
    });

    Handlebars.registerHelper("IsAdmin", function(user_id){
       
        if(window.group_creator_id == user_id){
            out = '<img src="img/group-admin.png" class="pAbsolute right30 top3" width="24px"/>';          
         }else{
            out = '';
         }
         console.log(out);
        return new Handlebars.SafeString(out); 
    });

    /**
     * If Greater Than
     * if_gt this compare=that
     */
    Handlebars.registerHelper('if_gt', function(context, options) {
        if (context > options.hash.compare)
            return options.fn(this);
        return options.inverse(this);
    });

    /**
     * Unless Greater Than
     * unless_gt this compare=that
     */
    Handlebars.registerHelper('unless_gt', function(context, options) {
        if (context > options.hash.compare)
            return options.inverse(this);
        return options.fn(this);
    });


    /**
     * If Less Than
     * if_lt this compare=that
     */
    Handlebars.registerHelper('if_lt', function(context, options) {
        if (context < options.hash.compare)
            return options.fn(this);
        return options.inverse(this);
    });

    /**
     * Unless Less Than
     * unless_lt this compare=that
     */
    Handlebars.registerHelper('unless_lt', function(context, options) {
        if (context < options.hash.compare)
            return options.inverse(this);
        return options.fn(this);
    });


    /**
     * If Greater Than or Equal To
     * if_gteq this compare=that
     */
    Handlebars.registerHelper('if_gteq', function(context, options) {
        if (context >= options.hash.compare)
            return options.fn(this);
        return options.inverse(this);
    });

    /**
     * Unless Greater Than or Equal To
     * unless_gteq this compare=that
     */
    Handlebars.registerHelper('unless_gteq', function(context, options) {
        if (context >= options.hash.compare)
            return options.inverse(this);
        return options.fn(this);
    });


    /**
     * If Less Than or Equal To
     * if_lteq this compare=that
     */
    Handlebars.registerHelper('if_lteq', function(context, options) {
        if (context <= options.hash.compare)
            return options.fn(this);
        return options.inverse(this);
    });

    

    /**
     * Unless Less Than or Equal To
     * unless_lteq this compare=that
     */
    Handlebars.registerHelper('unless_lteq', function(context, options) {
        if (context <= options.hash.compare)
            return options.inverse(this);
        return options.fn(this);
    });

    /**
     * Convert new line (\n\r) to <br>
     * from http://phpjs.org/functions/nl2br:480
     */
    Handlebars.registerHelper('nl2br', function(text) {
        text = Handlebars.Utils.escapeExpression(text);
        var nl2br = (text + '').replace(/([^>\r\n]?)(\r\n|\n\r|\r|\n)/g, '$1' + '<br>' + '$2');
        return new Handlebars.SafeString(nl2br);
    });

    /**
     * humanize contact designation , location null 
     * or ""
     */
    Handlebars.registerHelper('humanize_contacts', function(designation, location) {
        var out = "";
        if(designation == "null" || designation == "" || designation == null  ){
               out = out + "" 
        }else{
               out = out + designation 
        }

        if((designation != "null" && designation != "" && designation != null) && (location != "null" && location != "" && location != null  )){
            out = out + ", "
        }

        if(location == "null" || location == "" || location == null  ){
               out = out + "" 
        }else{
               out = out + location 
        }

        return new Handlebars.SafeString(out);
    });

    /**
     * humanize settings designation , location null 
     * or ""
     */
    Handlebars.registerHelper('humanize_settings', function(designation, department, location) {
        var out = "";
        if(designation == "null" || designation == "" || designation == null  ){
               out = out + "" 
        }else{
               out = out + designation 
        }

        if((designation != "null" && designation != "" && designation != null) && (department != "null" && department != "" && department != null  )){
            out = out + ", "
        }

        if(department == "null" || department == "" || department == null  ){
               out = out + "" 
        }else{
               out = out + department 
        }

        if((department != "null" && department != "" && department != null) && (location != "null" && location != "" && location != null  )){
            out = out + ", "
        }

        if(location == "null" || location == "" || location == null  ){
               out = out + "" 
        }else{
               out = out + location 
        }

        return new Handlebars.SafeString(out);
    });

    /**
     * If Address is there
     * or not
     */
    Handlebars.registerHelper('if_address', function(street, city, state, zip, country, options) {
        out = ""
        if((street == "" || street == null) && (city == "" || city == null) && (state == "" || state == null) && (zip == "" || zip == null) && (country == "" || country == null)){
            out = ''
        }else{
            out = '<h2 class="title3"><img src="img/address-icon.png" width="12" /> Address </h2>'
        }
        return new Handlebars.SafeString(out);
    });

    /**
     * If Telephone is there
     * or not
     */
    Handlebars.registerHelper('if_telephone', function(work, mobile, home) {
        out = ""
        if((work == "" || work == null) && (mobile == "" || mobile == null) && (home == "" || home == null) ){
            out = ''
        }else{
            out = '<h2 class="title3"><img src="img/phone-icon.png" width="17" /> Telephone</h2>'
        }
        return new Handlebars.SafeString(out);
    });

    /**
     * If Telephone is there
     * or not
     */
    Handlebars.registerHelper('if_emergency', function(name, relationship, blood_group, work, home, mobile) {
        out = ""
        if((name == "" || name == null) && (relationship == "" || relationship == null) && (blood_group == "" || blood_group == null) && (work == "" || work == null) && (home == "" || home == null) && (mobile == "" || mobile == null)){
            out = ''
        }else{
            out = '<h2 class="title3"><img src="img/emergency-icon.png" width="16" /> Emergency Contact Detail</h2>'
        }
        return new Handlebars.SafeString(out);
    });

}));