/**
* encode special HTML characters, so text is safe when building HTML dynamically
* @param {String} text the text to encode
* @return {String}
*/
var encodeHTML = (function() {
 
    var encodeHTMLmap = {
        "'" : "'",
        '"' : "&quot;",
        "<" : "&lt;",
        ">" : "&gt;",
        "(" : "&#40;",
        ")" : "&#41;",
        "\\": "&#92;&#92;"  
    };
 
    /**
    * encode character as HTML entity
    * @param {String} ch character to map to entity
    * @return {String}
    */
    function encodeHTMLmapper(ch) {
        return encodeHTMLmap[ch];
    }
 
    return function(text) {
        // search for HTML special characters, convert to HTML entities
        text = text.replace(/\n/g, " ");
        text = text.replace(/[\\]/g,"&#92;");
        return text.replace(/["'<>]/g, encodeHTMLmapper);
    };
 
})();

// Converting sanitised html back to displayable html
String.prototype.deentitize = function() {
    var ret = this.replace(/&amp;/g, '&');
    ret = ret.replace(/&lt;/g, '<');
    ret = ret.replace(/&quot;/g, '"');
    ret = ret.replace(/&apos;/g, "'");
    ret = ret.replace(/&gt;/g, '>');
    ret = ret.replace(/&#40;/g,"(");
    ret = ret.replace(/&#41;/g,")");
    ret = ret.replace(/&#039;/g,"'");
    ret = ret.replace(/&#92;&#92;/g,"\\"); 
    ret = ret.replace(/&#92;/g,"\\");    
    return ret;
};